;; Generated package description from embark.el  -*- no-byte-compile: t -*-
(define-package "embark" "0.17" "Conveniently act on minibuffer completions" '((emacs "26.1")) :commit "97270d725761ee02db461b45b18ec16ae31f203e" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
